@@ -87,6 +87,8 @@
  * ```
  **/
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 struct _PeasExtensionSetPrivate {
   PeasEngine *engine;
   GType exten_type;
@@ -108,6 +110,8 @@ typedef struct {
   GParameter *parameters;
 } PeasParameterArray;
 
+G_GNUC_END_IGNORE_DEPRECATIONS
+
 /* Signals */
 enum {
   EXTENSION_ADDED,
@@ -145,7 +149,9 @@ set_construct_properties (PeasExtensionSet   *set,
 
   priv->n_parameters = array->n_parameters;
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   priv->parameters = g_new0 (GParameter, array->n_parameters);
+  G_GNUC_END_IGNORE_DEPRECATIONS
 
   for (i = 0; i < array->n_parameters; i++)
     {
@@ -546,13 +552,13 @@ peas_extension_set_call_valist (PeasExtensionSet *set,
       return FALSE;
     }
 
-  n_args = g_callable_info_get_n_args (callable_info);
+  n_args = gi_callable_info_get_n_args (callable_info);
   g_return_val_if_fail (n_args >= 0, FALSE);
 
   args = g_newa (GIArgument, n_args);
   peas_gi_valist_to_arguments (callable_info, va_args, args, NULL);
 
-  g_base_info_unref ((GIBaseInfo *) callable_info);
+  gi_base_info_unref ((GIBaseInfo *) callable_info);
 
   return peas_extension_set_callv (set, method_name, args);
 }
@@ -612,6 +618,7 @@ peas_extension_set_foreach (PeasExtensionSet            *set,
     }
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 /**
  * peas_extension_set_newv: (skip)
  * @engine: (allow-none): A #PeasEngine, or %NULL.
@@ -764,6 +771,7 @@ peas_extension_set_new_valist (PeasEngine  *engine,
 
   return set;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * peas_extension_set_new: (skip)
