@@ -111,6 +111,7 @@ peas_object_module_load (GTypeModule *gmodule)
       GModuleFlags flags = 0;
       gchar *fallback_path = NULL;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 #ifdef G_OS_WIN32
       if (!g_str_has_suffix (priv->module_name, "." G_MODULE_SUFFIX))
         {
@@ -134,6 +135,7 @@ peas_object_module_load (GTypeModule *gmodule)
        * is only the .la file in the build directory.
        */
       path = g_module_build_path (priv->path, priv->module_name);
+G_GNUC_END_IGNORE_DEPRECATIONS
 
       if (G_MODULE_SUFFIX[0] != '\0' && g_str_has_suffix (path, "." G_MODULE_SUFFIX))
         path[strlen (path) - strlen (G_MODULE_SUFFIX) - 1] = '\0';
@@ -458,6 +460,7 @@ peas_object_module_new_embedded (const gchar *module_name,
                                            NULL));
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 /**
  * peas_object_module_create_object: (skip)
  * @module: A #PeasObjectModule.
@@ -499,6 +502,7 @@ peas_object_module_create_object (PeasObjectModule *module,
 
   return NULL;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * peas_object_module_provides_object: (skip)
@@ -650,6 +654,7 @@ peas_object_module_register_extension_factory (PeasObjectModule *module,
   g_debug ("Registered extension for type '%s'", g_type_name (exten_type));
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 static GObject *
 create_gobject_from_type (guint       n_parameters,
                           GParameter *parameters,
@@ -679,6 +684,7 @@ create_gobject_from_type (guint       n_parameters,
 
   return G_OBJECT (g_object_newv (impl_type, n_parameters, parameters));
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * peas_object_module_register_extension_type:
