@@ -23,7 +23,7 @@
 #include <config.h>
 #endif
 
-#include <girepository.h>
+#include <girepository/girepository.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <locale.h>
@@ -131,14 +131,18 @@ main (int    argc,
 
   if (run_from_build_dir)
     {
+      GIRepository *repository = gi_repository_dup_default ();
+
       g_debug ("Running from build directory: %s", PEAS_BUILDDIR);
 
       /* Use the uninstalled typelibs */
-      g_irepository_prepend_search_path (PEAS_BUILDDIR "/libpeas");
-      g_irepository_prepend_search_path (PEAS_BUILDDIR "/libpeas-gtk");
+      gi_repository_prepend_search_path (repository, PEAS_BUILDDIR "/libpeas");
+      gi_repository_prepend_search_path (repository, PEAS_BUILDDIR "/libpeas-gtk");
 
       /* Use the uninstalled plugin loaders */
       g_setenv ("PEAS_PLUGIN_LOADERS_DIR", PEAS_BUILDDIR "/loaders", TRUE);
+
+      g_clear_object (&repository);
     }
 
   engine = peas_engine_get_default ();
@@ -155,8 +159,10 @@ main (int    argc,
     peas_engine_add_search_path (engine, PEAS_BUILDDIR "/peas-demo/plugins", NULL);
   else
     {
+#ifdef G_OS_WIN32
       char *prefix;
       char *demo_pluginlibdir, *demo_plugindatadir;
+#endif
 
       peas_engine_add_search_path (engine,
                                    PEAS_LIBDIR "/peas-demo/plugins/",
